@@ -6,6 +6,7 @@
  */
 
 #include "Vector.h"
+
 #include "Matrix.h"
 
 namespace NetworKit {
@@ -20,9 +21,6 @@ Vector::Vector(const std::vector<double> &values, const bool transpose) : values
 Vector::Vector(const std::initializer_list<double> &list) : values(list), transposed(false) {
 }
 
-Vector::Vector(const Vector &other) : values(other.values), transposed(other.transposed) {
-}
-
 bool Vector::isTransposed() const {
 	return transposed;
 }
@@ -37,10 +35,19 @@ double Vector::length() const {
 	return std::sqrt(this->transpose() * (*this));
 }
 
+double Vector::mean() const {
+	double sum = 0.0;
+	this->forElements([&](double value){
+		sum += value;
+	});
+
+	return sum / (double) this->getDimension();
+}
+
 bool Vector::operator==(const Vector &other) const {
 	if (getDimension() != other.getDimension() || isTransposed() != other.isTransposed()) return false;
 
-	for (count i = 0; i < getDimension(); i++) {
+	for (index i = 0; i < getDimension(); i++) {
 		if (values[i] != other[i]) return false;
 	}
 
@@ -51,6 +58,16 @@ bool Vector::operator!=(const Vector &other) const {
 	return !(*this == other);
 }
 
+double Vector::innerProduct(const Vector &v1, const Vector &v2) {
+	assert(v1.getDimension() == v2.getDimension());
+	double scalar = 0.0;
+	for (index i = 0; i < v1.getDimension(); ++i) {
+		scalar += v1[i] * v2[i];
+	}
+
+	return scalar;
+}
+
 Matrix Vector::outerProduct(const Vector &v1, const Vector &v2) {
 	std::vector<Vector> rows(v1.getDimension(), Vector(v2.getDimension(), 0.0));
 
@@ -64,36 +81,16 @@ Matrix Vector::outerProduct(const Vector &v1, const Vector &v2) {
 	return Matrix(rows);
 }
 
-double Vector::innerProduct(const Vector &v1, const Vector &v2) {
-	if (v1.getDimension() != v2.getDimension()) {
-		throw std::runtime_error("Vector::innerProduct(const Vector &v1, const Vector &v2): dimensions do not match");
-	}
-
-	double result = 0.0;
-#pragma omp parallel for reduction(+:result)
-	for (index i = 0; i < v1.getDimension(); ++i) {
-		result += v1[i] * v2[i];
-	}
-
-	return result;
-}
-
 double Vector::operator*(const Vector &other) const {
-	if (!isTransposed() || other.isTransposed()) {
-		throw std::runtime_error("vectors are not transposed correctly for inner product");
-	} else if (getDimension() != other.getDimension()) {
-		throw std::runtime_error("dimensions of vectors do not match");
-	}
+	assert(isTransposed() && !other.isTransposed()); // vectors must be transposed correctly for inner product
+	assert(getDimension() == other.getDimension()); // dimensions of vectors must match
 
 	return innerProduct(*this, other);
 }
 
 Vector Vector::operator*(const Matrix &matrix) const {
-	if (!isTransposed()) {
-		throw std::runtime_error("vector must be of the form 1xn");
-	} else if (getDimension() != matrix.numberOfRows()) {
-		throw std::runtime_error("dimensions of vector and matrix do not match");
-	}
+	assert(isTransposed()); // vector must be of the form 1xn
+	assert(getDimension() == matrix.numberOfRows()); // dimensions of vector and matrix must match
 
 	Vector result(matrix.numberOfColumns(), 0.0, true);
 #pragma omp parallel for
@@ -130,12 +127,13 @@ Vector Vector::operator+(const Vector &other) const {
 	return Vector(*this) += other;
 }
 
+Vector Vector::operator+(const double value) const {
+	return Vector(*this) += value;
+}
+
 Vector& Vector::operator+=(const Vector &other) {
-	if (isTransposed() != other.isTransposed()) {
-		throw std::runtime_error("vectors are not transformed correctly");
-	} else if (getDimension() != other.getDimension()) {
-		throw std::runtime_error("dimensions of vectors do not match");
-	}
+	assert(isTransposed() == other.isTransposed()); // vectors must be transposed correctly
+	assert(getDimension() == other.getDimension()); // dimensions of vectors must match
 
 #pragma omp parallel for
 	for (count i = 0; i < getDimension(); i++) {
@@ -145,16 +143,26 @@ Vector& Vector::operator+=(const Vector &other) {
 	return *this;
 }
 
+Vector& Vector::operator+=(const double value) {
+#pragma omp parallel for
+	for (count i = 0; i < getDimension(); ++i) {
+		values[i] += value;
+	}
+
+	return *this;
+}
+
 Vector Vector::operator-(const Vector &other) const {
 	return Vector(*this) -= other;
 }
 
+Vector Vector::operator-(const double value) const {
+	return Vector(*this) += value;
+}
+
 Vector& Vector::operator-=(const Vector &other) {
-	if (isTransposed() != other.isTransposed()) {
-		throw std::runtime_error("vectors are not transformed correctly");
-	} else if (getDimension() != other.getDimension()) {
-		throw std::runtime_error("dimensions of vectors do not match");
-	}
+	assert(isTransposed() == other.isTransposed()); // vectors must be transposed correctly
+	assert(getDimension() == other.getDimension()); // dimensions of vectors must match
 
 #pragma omp parallel for
 	for (count i = 0; i < getDimension(); i++) {
@@ -164,6 +172,15 @@ Vector& Vector::operator-=(const Vector &other) {
 	return *this;
 }
 
+Vector& Vector::operator-=(const double value) {
+#pragma omp parallel for
+	for (count i = 0; i < getDimension(); ++i) {
+		values[i] -= value;
+	}
+
+	return *this;
+}
+
 
 } /* namespace NetworKit */
 
