@@ -10,6 +10,7 @@
 
 #include <vector>
 #include "../Globals.h"
+#include <cassert>
 
 namespace NetworKit {
 
@@ -50,8 +51,21 @@ public:
 	 */
 	Vector(const std::initializer_list<double> &list);
 
-	/** Copy constructor */
-	Vector(const Vector &other);
+	/** Default copy constructor */
+	Vector(const Vector &other) = default;
+
+	/** Default move constructor */
+	Vector(Vector &&other) = default;
+
+	/** Default destructor */
+	virtual ~Vector() = default;
+
+	/** Default copy assignment operator */
+	Vector& operator=(const Vector &other) = default;
+
+	/** Default move assignment operator */
+	Vector& operator=(Vector &&other) = default;
+
 
 	/**
 	 * @return dimension of vector
@@ -78,12 +92,20 @@ public:
 	 */
 	double length() const;
 
+
+	/**
+	 * Calculates and returns the arithmetic mean of this vector
+	 * @return The arithmetic mean of this vector.
+	 */
+	double mean() const;
+
 	/**
 	 * Returns a reference to the element at index @a idx without checking the range of this vector.
 	 * @param idx The index of the element.
 	 * @return Reference to the element at index @a idx.
 	 */
 	inline double& operator[](const index idx) {
+		assert(idx < values.size());
 		return values[idx];
 	}
 
@@ -93,6 +115,7 @@ public:
 	 * @return Constant reference to the element at index @a idx.
 	 */
 	inline const double& operator[](const index idx) const {
+		assert(idx < values.size());
 		return values[idx];
 	}
 
@@ -109,19 +132,6 @@ public:
 		}
 	}
 
-	/**
-	 * Returns a constant reference to the element at index @a idx. If @a idx is not a valid index an exception is thrown.
-	 * @param idx The index of the element.
-	 * @return Reference to the element at index @a idx.
-	 */
-	const double &at(const index idx) const {
-		if (idx >= values.size()) {
-			throw std::runtime_error("index out of range");
-		} else {
-			return values[idx];
-		}
-	}
-
 	/**
 	 * Compares this vector and @a other element-wise.
 	 * @return True, if this vector is element-wise equal to @a other, otherwise false.
@@ -193,6 +203,11 @@ public:
 	 */
 	Vector operator+(const Vector &other) const;
 
+	/**
+	 * Adds @a value to each element of this vector and returns the result.
+	 */
+	Vector operator+(const double value) const;
+
 	/**
 	 * Adds @a other to this vector.
 	 * Note that the dimensions of the vectors have to be the same.
@@ -200,6 +215,11 @@ public:
 	 */
 	Vector& operator+=(const Vector &other);
 
+	/**
+	 * Adds @a value to each element of this vector.
+	 */
+	Vector& operator+=(const double value);
+
 	/**
 	 * Subtracts @a other from this vector and returns the result.
 	 * Note that the dimensions of the vectors have to be the same.
@@ -208,6 +228,11 @@ public:
 	 */
 	Vector operator-(const Vector &other) const;
 
+	/**
+	 * Subtracts @a value from each element of this vector and returns the result.
+	 */
+	Vector operator-(const double value) const;
+
 	/**
 	 * Subtracts @a other from this vector.
 	 * Note that the dimensions of the vectors have to be the same.
@@ -215,6 +240,11 @@ public:
 	 */
 	Vector& operator-=(const Vector &other);
 
+	/**
+	 * Subtracts @a value from each element of this vector.
+	 */
+	Vector& operator-=(const double value);
+
 	/**
 	 * Iterate over all elements of the vector and call handler (lambda closure).
 	 */
