@@ -6,33 +6,37 @@
  */
 
 #include "DegreeCentrality.h"
-#include <algorithm>
 
 namespace NetworKit {
 
-DegreeCentrality::DegreeCentrality(const Graph& G, bool normalized) : Centrality(G, normalized) {
+DegreeCentrality::DegreeCentrality(const Graph& G, bool normalized, bool outDeg, bool ignoreSelfLoops) : Centrality(G, normalized), outDeg(outDeg), ignoreSelfLoops(ignoreSelfLoops) {
 }
 
 void DegreeCentrality::run() {
 	scoreData = std::vector<double>(G.upperNodeIdBound(), 0.0);
 
-	G.parallelForNodes([&](node u) {
-		scoreData[u] = G.degree(u);
-	});
+	if (G.isDirected() && !outDeg) {
+		G.parallelForNodes([&](node u) {
+			scoreData[u] = G.degreeIn(u);
+		});
+	} else {
+		G.parallelForNodes([&](node u) {
+			scoreData[u] = G.degree(u);
+		});
+	}
 
 	if (normalized) {
-		count maxDeg = *std::max_element(scoreData.begin(), scoreData.end());
+		count maxDeg = maximum();
 		G.parallelForNodes([&](node u) {
 			scoreData[u] = scoreData[u] / maxDeg;
 		});
 	}
-
 	hasRun = true;
 }
 
 
 double DegreeCentrality::maximum() {
-	return G.numberOfNodes() - 1;
+	return G.numberOfNodes() - ignoreSelfLoops;
 }
 
 
