@@ -19,11 +19,12 @@ namespace NetworKit {
  */
 class ParallelPartitionCoarsening: public NetworKit::GraphCoarsening {
 public:
-	ParallelPartitionCoarsening(bool useGraphBuilder = true);
+	ParallelPartitionCoarsening(const Graph& G, const Partition& zeta, bool useGraphBuilder = true);
 
-	virtual std::pair<Graph, std::vector<node> > run(const Graph& G, const Partition& zeta);
+	virtual void run();
 
 private:
+	const Partition& zeta;
 	bool useGraphBuilder;
 };
 
