@@ -7,7 +7,6 @@
 
 #include "PrefixJaccardScore.h"
 #include <omp.h>
-#include "../auxiliary/Parallel.h"
 
 namespace NetworKit {
 
@@ -60,7 +59,7 @@ void PrefixJaccardScore<AttributeT>::run() {
 		const auto beginIt = rankedEdges.begin() + rankedEdgeBegin[u];
 		const auto endIt = rankedEdges.begin() + rankedEdgeBegin[u+1];
 
-		Aux::Parallel::sort(beginIt, endIt, std::greater<RankedEdge>());
+		std::sort(beginIt, endIt, std::greater<RankedEdge>());
 
 		AttributeT curVal = beginIt->att;
 		count curRank = 0;
