@@ -40,11 +40,18 @@ Graph ClusteredRandomGraphGenerator::generate() {
 		}
 	});
 
+	this->zeta = std::move(zeta);
+
 	G.shrinkToFit();
 	return G;
 
 }
 
+Partition ClusteredRandomGraphGenerator::getCommunities() {
+	return zeta;
+}
+
+
 } /* namespace NetworKit */
 
 
