@@ -32,7 +32,7 @@ void BFS::run() {
 	}
 
 	if (storeStack) {
-		std::stack<node> empty;
+		std::vector<node> empty;
 		std::swap(stack, empty);
 	}
 
@@ -46,7 +46,7 @@ void BFS::run() {
 		q.pop();
 
 		if (storeStack) {
-			stack.push(u);
+			stack.push_back(u);
 		}
 		if (breakWhenFound && target == u) {
 			break;
