@@ -15,6 +15,7 @@
 #include <utility>
 #include <stdexcept>
 #include <functional>
+#include <unordered_set>
 
 #include "../Globals.h"
 #include "Coordinates.h"
@@ -25,6 +26,52 @@
 
 namespace NetworKit {
 
+
+/**
+ * A weighted edge used for the graph constructor with
+ * initializer list syntax.
+ */
+struct WeightedEdge {
+  node u, v;
+  edgeweight weight;
+
+  WeightedEdge(node u, node v, edgeweight w) : u(u), v(v), weight(w) {
+  }
+};
+inline bool operator<(const WeightedEdge& e1, const WeightedEdge& e2) {
+  return e1.weight < e2.weight;
+}
+struct Edge {
+  node u, v;
+
+  Edge(node _u, node _v, bool sorted = false) {
+    if (sorted) {
+      u = std::min(_u, _v);
+      v = std::max(_u, _v);
+    } else {
+      u = _u;
+      v = _v;
+    }
+  }
+};
+inline bool operator==(const Edge& e1, const Edge& e2) {
+  return e1.u == e2.u && e1.v == e2.v;
+}
+}
+
+namespace std {
+  template<>
+  struct hash<NetworKit::Edge> {
+    size_t operator()(const NetworKit::Edge& e) const {
+      return hash_node(e.u) ^ hash_node(e.v);
+    }
+
+    hash<NetworKit::node> hash_node;
+  };
+}
+
+namespace NetworKit {
+
 /**
  * @ingroup graph
  * A graph (with optional weights) and parallel iterator methods.
@@ -319,6 +366,14 @@ public:
 
 	Graph(const Graph& G, bool weighted, bool directed);
 
+	/**
+	   * Generate a weighted graph from a list of edges. (Useful for small
+	   * graphs in unit tests that you do not want to read from a file.)
+	   *
+	   * @param[in] edges list of weighted edges
+	   */
+	  Graph(std::initializer_list<WeightedEdge> edges);
+
 
 	/**
 	 * Create a graph as copy of @a other.
@@ -479,6 +534,28 @@ public:
 	void restoreNode(node v);
 
 
+	// SET OPERATIONS
+
+	/**
+	 * Appends another graph to this graph as a new subgraph. Performs node
+	 * id remapping.
+	 * @param G [description]
+	 */
+	void append(const Graph& G);
+
+	/**
+	 * Modifies this graph to be the union of it and another graph.
+	 * Nodes with the same ids are identified with each other.
+	 * @param G [description]
+	 */
+	void merge(const Graph& G);
+
+
+	// SUBGRAPHS
+
+	Graph subgraphFromNodes(const std::unordered_set<node>& nodes) const;
+
+
 	/** NODE PROPERTIES **/
 
 	/**
@@ -834,6 +911,14 @@ public:
 	*/
 	Graph toUndirected() const;
 
+
+	/**
+	* Return an unweighted version of this graph.
+	*
+	* @return unweighted graph.
+	*/
+	Graph toUnweighted() const;
+
 	/**
 	 * Return the transpose of this graph. The graph must be directed.
 	 *
@@ -1495,6 +1580,9 @@ void Graph::DFSEdgesFrom(node r, L handle) const {
 	} while (!s.empty());
 }
 
+
+
+
 } /* namespace NetworKit */
 
 #endif /* GRAPH_H_ */
