@@ -21,11 +21,6 @@ namespace NetworKit {
  */ 
 class DotGraphWriter {
 public:
-	/**
-	 * Constructor. No arguments required.
-	 */
-	virtual ~DotGraphWriter() = default;
-
 	/**
 	 * Write a graph as a GraphViz/file.
 	 * 
