@@ -9,7 +9,7 @@
 #define MAXENTSTRESS_H_
 
 #include "Layouter.h"
-#include "../distmeasures/AlgebraicDistance.h"
+#include "../linkprediction/AlgebraicDistanceIndex.h"
 
 namespace NetworKit {
 
