@@ -6,12 +6,19 @@ from _NetworKit import Graph as __Graph
 # local imports
 from .GraphMLIO import GraphMLReader, GraphMLWriter
 from .GEXFIO import GEXFReader, GEXFWriter
+from . import algebraic
 
 # external imports
 import os
 import logging
-import numpy
-import scipy.io
+try:
+	import numpy
+except ImportError:
+	print("module 'numpy' not available - some functionality will be restricted")
+try:
+	import scipy.io
+except ImportError:
+	print("module 'scipy' not available - some functionality will be restricted")
 import fnmatch
 
 try:
@@ -134,7 +141,7 @@ def readGraph(path, fileformat, **kwargs):
 				raise IOError("{0} is not a valid {1} file: {2}".format(path,fileformat,e))
 	return None
 
-def readGraphs(dirPath, pattern, fileformat, some=None, **kwargs):
+def readGraphs(dirPath, pattern, fileformat, some=None, exclude=None, **kwargs):
 	"""
 	Read all graph files contained in a directory whose filename contains the pattern, return a dictionary of name to Graph object.
     Parameters:
@@ -149,22 +156,23 @@ def readGraphs(dirPath, pattern, fileformat, some=None, **kwargs):
 	for root, dirs, files in os.walk(dirPath):
 		for file in files:
 			if fnmatch.fnmatch(file, pattern):
-				G = readGraph(os.path.join(root, file), fileformat, **kwargs)
-				graphs[G.getName()] = G
-				if some:
-					if len(graphs) == some:
-						return graphs
+				if (exclude is None) or (not fnmatch.fnmatch(file, exclude)):
+					G = readGraph(os.path.join(root, file), fileformat, **kwargs)
+					graphs[G.getName()] = G
+					if some:
+						if len(graphs) == some:
+							return graphs
 	return graphs
 
 
 class MatReader:
-	def __init__(self, key = "A"):
+	def __init__(self, key = "G"):
 		self.key = key
 
 	def read(self, path):
 		return readMat(path, self.key)
 
-def readMat(path, key="A"):
+def readMat(path, key="G"):
 	""" Reads a Graph from a matlab object file containing an adjacency matrix and returns a NetworKit::Graph
 		Parameters:
 		- key: The key of the adjacency matrix in the matlab object file (default: A)"""
@@ -186,6 +194,23 @@ def readMat(path, key="A"):
 			G.addEdge(u, v)
 	return G
 
+class MatWriter:
+	def __init__(self):
+		self.key = key
+
+	def write(self, G, path, key="G"):
+		writeMat(path, key)
+
+def writeMat(G, path, key="G"):
+	""" Writes a NetworKit::Graph to a Matlab object file.
+		Parameters:
+		- G: The graph
+		- path: Path of the matlab file
+		- key: Dictionary Key
+	"""
+	matrix = algebraic.adjacencyMatrix(G, matrixType='sparse')
+	scipy.io.savemat(path, {key : matrix})
+
 
 # writing
 def getWriter(fileformat, **kwargs):
@@ -285,11 +310,3 @@ def writeStream(stream, path):
 		Write a graph event stream to a file.
 	"""
 	DGSWriter().write(stream, path)
-
-
-def graphFromStreamFile(path, mapped=True, baseIndex=0):
-	stream = readStream(path, mapped, baseIndex)
-	G = __Graph()
-	gu = GraphUpdater(G)
-	gu.update(stream)
-	return G
